@@ -3,8 +3,8 @@ package Class::MOP::Method::Generated;
 BEGIN {
   $Class::MOP::Method::Generated::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Class::MOP::Method::Generated::VERSION = '2.0105'; # TRIAL
+{
+  $Class::MOP::Method::Generated::VERSION = '2.0300'; # TRIAL
 }
 
 use strict;
@@ -69,14 +69,20 @@ sub _compile_code {
 
 1;
 
-__END__
+# ABSTRACT: Abstract base class for generated methods
+
+
 
 =pod
 
-=head1 NAME 
+=head1 NAME
 
 Class::MOP::Method::Generated - Abstract base class for generated methods
 
+=head1 VERSION
+
+version 2.0300
+
 =head1 DESCRIPTION
 
 This is a C<Class::MOP::Method> subclass which is subclassed by
@@ -85,5 +91,20 @@ C<Class::MOP::Method::Constructor>.
 
 It is not intended to be used directly.
 
+=head1 AUTHOR
+
+Stevan Little <stevan@iinteractive.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by Infinity Interactive, Inc..
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+
+__END__
+
+
