@@ -2,10 +2,12 @@ package Moose::Meta::Attribute::Native;
 BEGIN {
   $Moose::Meta::Attribute::Native::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Meta::Attribute::Native::VERSION = '2.0105'; # TRIAL
+{
+  $Moose::Meta::Attribute::Native::VERSION = '2.0300'; # TRIAL
 }
 
+use Class::Load qw(load_class);
+
 my @trait_names = qw(Bool Counter Number String Array Hash Code);
 
 for my $trait_name (@trait_names) {
@@ -23,7 +25,7 @@ for my $trait_name (@trait_names) {
     $meta->add_method(register_implementation => sub {
         # resolve_metatrait_alias will load classes anyway, but throws away
         # their error message; we WANT to die if there's a problem
-        Class::MOP::load_class($trait_class);
+        load_class($trait_class);
         return $trait_class;
     });
 }
@@ -42,7 +44,7 @@ Moose::Meta::Attribute::Native - Delegate to native Perl types
 
 =head1 VERSION
 
-version 2.0105
+version 2.0300
 
 =head1 SYNOPSIS
 
