@@ -2,14 +2,15 @@ package Moose::Meta::Role::Composite;
 BEGIN {
   $Moose::Meta::Role::Composite::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Meta::Role::Composite::VERSION = '2.0105'; # TRIAL
+{
+  $Moose::Meta::Role::Composite::VERSION = '2.0300'; # TRIAL
 }
 
 use strict;
 use warnings;
 use metaclass;
 
+use Class::Load qw(load_class);
 use Scalar::Util 'blessed';
 
 use base 'Moose::Meta::Role';
@@ -126,7 +127,7 @@ sub get_method {
 
 sub apply_params {
     my ($self, $role_params) = @_;
-    Class::MOP::load_class($self->application_role_summation_class);
+    load_class($self->application_role_summation_class);
 
     $self->application_role_summation_class->new(
         role_params => $role_params,
@@ -165,7 +166,7 @@ Moose::Meta::Role::Composite - An object to represent the set of roles
 
 =head1 VERSION
 
-version 2.0105
+version 2.0300
 
 =head1 DESCRIPTION
 
