@@ -2,13 +2,14 @@ package Moose::Util;
 BEGIN {
   $Moose::Util::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $Moose::Util::VERSION = '2.0105'; # TRIAL
+{
+  $Moose::Util::VERSION = '2.0300'; # TRIAL
 }
 
 use strict;
 use warnings;
 
+use Class::Load qw(load_class load_first_existing_class);
 use Data::OptList;
 use Params::Util qw( _STRING );
 use Sub::Exporter;
@@ -50,7 +51,7 @@ sub find_meta { Class::MOP::class_of(@_) }
 sub does_role {
     my ($class_or_obj, $role) = @_;
 
-    if (try { $class_or_obj->can('does') }) {
+    if (try { $class_or_obj->isa('Moose::Object') }) {
         return $class_or_obj->does($role);
     }
 
@@ -128,7 +129,7 @@ sub _apply_all_roles {
             $meta = $role->[0];
         }
         else {
-            Class::MOP::load_class( $role->[0] , $role->[1] );
+            load_class( $role->[0] , $role->[1] );
             $meta = find_meta( $role->[0] );
         }
 
@@ -148,7 +149,7 @@ sub _apply_all_roles {
 
     return unless @role_metas;
 
-    Class::MOP::load_class($applicant)
+    load_class($applicant)
         unless blessed($applicant)
             || Class::MOP::class_of($applicant);
 
@@ -221,7 +222,7 @@ sub _build_alias_package_name {
             $type, $metaclass_name, $options{trait}
         );
 
-        my $loaded_class = Class::MOP::load_first_existing_class(
+        my $loaded_class = load_first_existing_class(
             $possible_full_name,
             $metaclass_name
         );
@@ -487,7 +488,7 @@ Moose::Util - Utilities for working with Moose classes
 
 =head1 VERSION
 
-version 2.0105
+version 2.0300
 
 =head1 SYNOPSIS
 
